import json
from pathlib import Path

from hello_class import Hello, json_to_text


def test_json_to_text(tmp_path: Path) -> None:
    json_file = tmp_path / "input.json"
    output_file = tmp_path / "output.txt"

    json_file.write_text(json.dumps([{"foo": "bar"}]))

    json_to_text(json_file, output_file)

    assert output_file.read_text() == "foo:bar\n"


def test_json_to_text_multiple_items(tmp_path: Path) -> None:
    json_file = tmp_path / "input.json"
    output_file = tmp_path / "output.txt"

    json_file.write_text(json.dumps([{"foo": "bar"}, {"baz": "qux"}]))

    json_to_text(json_file, output_file)

    assert output_file.read_text() == "foo:bar\nbaz:qux\n"


def test_json_to_text_multiple_keys(tmp_path: Path) -> None:
    json_file = tmp_path / "input.json"
    output_file = tmp_path / "output.txt"

    json_file.write_text(json.dumps([{"foo": "bar", "baz": "qux"}]))

    json_to_text(json_file, output_file)

    content = output_file.read_text()
    assert "foo:bar" in content
    assert "baz:qux" in content


def test_hello_init() -> None:
    hello = Hello("World")
    assert hello.name == "World"


def test_hello_greet() -> None:
    hello = Hello("World")
    assert hello.greet() == "Hello, World!"


def test_hello_greet_with_name() -> None:
    hello = Hello("Johan")
    assert hello.greet() == "Hello, Johan!"



"""Hello class package."""

__version__ = "0.2.1"

import json
from pathlib import Path


def json_to_text(json_path: str | Path, output_path: str | Path) -> None:
    """Parse a JSON file and write key:value pairs to a text file.

    Args:
        json_path: Path to the input JSON file.
        output_path: Path to the output text file.
    """
    json_path = Path(json_path)
    output_path = Path(output_path)

    with json_path.open() as f:
        data = json.load(f)

    lines: list[str] = []
    for item in data:
        for key, value in item.items():
            lines.append(f"{key}:{value}")

    output_path.write_text("\n".join(lines) + "\n")


class Hello:
    """A simple greeting class."""

    def __init__(self, name: str) -> None:
        self.name = name

    def greet(self) -> str:
        """Return a greeting message."""
        return f"Hello, {self.name}!"
